@@ -9,7 +9,7 @@ use Flickr::API2::Interestingness;
 use Flickr::API2::People;
 use Flickr::API2::Raw;
 
-our $VERSION = '2.06';
+our $VERSION = '2.07';
 
 sub new {
     my $class   = shift;
@@ -21,7 +21,7 @@ sub new {
     my $self = {
         _raw => Flickr::API2::Raw->new($options),
         rest_uri => $options->{rest_uri}
-          || 'http://api.flickr.com/services/rest/',
+          || 'https://api.flickr.com/services/rest/',
     };
 
     bless $self, $class;
